name

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2020 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NormalizePython

func NormalizePython(name string) string

NormalizePython takes a Python package name and returns it in normalized form. Specifically, that means it is in all lower case and all periods (.) and underscores (_) with hyphens. See https://www.python.org/dev/peps/pep-0503/#name for ddetails on how names should be normalized in Python.

Types

This section is empty.

Jump to